# todxpy
Python version of TodX

Probable I should add more readme stuff

To install the program run `pip install todx`

Currently the supported commands are:

## `--add` or `-a`

Format: `todx --add [content] [list](optional) [status](optional)`

## `--view`

Format: `todx --view [list title](optional, defaults to inbox)`

## `--all`

Format: `todx --all`
